bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.plates
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: GaussianGammaToGaussianWishart.plates